@@ -1,4 +1,4 @@
-`Drawdowns` <-
+Drawdowns <-
 function (R, geometric = TRUE, ...)
 { # @author Peter Carl
 
@@ -41,27 +41,9 @@ function (R, geometric = TRUE, ...)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: Drawdowns.R 1510 2010-01-04 03:41:19Z peter_carl $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.5  2009-09-22 02:56:13  peter
-# - added reclass
-#
-# Revision 1.4  2009-08-31 20:51:27  brian
-# - add new function na.skip to deal with non-contiguous NA's in data, may eventually go to xts
-# - fix components of charts.PerformanceSummary to use na.skip
-#
-# Revision 1.3  2009-06-02 03:14:49  peter
-# - converted internal to xts, removed zoo coersion
-#
-# Revision 1.2  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.1  2007/03/21 14:09:10  peter
-# - separated function from the chart.Drawdowns.R
+# $Id: Drawdowns.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
