@@ -1,4 +1,4 @@
-`UpsidePotentialRatio` <-
+UpsidePotentialRatio <-
 function (R, MAR = 0, method=c("subset","full"))
 { # @author Brian G. Peterson
 
@@ -35,7 +35,7 @@ function (R, MAR = 0, method=c("subset","full"))
     }
 }
 
-`UPR`<-
+UPR<-
 function (R, MAR = 0, method=c("subset","full"))
 { # @author Brian G. Peterson
     UpsidePotentialRatio(R=R, MAR=MAR, method=method)
@@ -46,35 +46,9 @@ function (R, MAR = 0, method=c("subset","full"))
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: UpsidePotentialRatio.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.7  2009-10-06 15:14:44  peter
-# - fixed rownames
-# - fixed scale = 12 replacement errors
-#
-# Revision 1.5  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.4  2009-10-01 01:47:53  peter
-# - added multi-column support
-#
-# Revision 1.3  2008-09-30 21:17:24  brian
-# - both DownsideDeviation and UpsidePotentialRatio now support "method argument to use full or subset of series
-# - use subset as default method
-# - updated documentation to reflect change
-#
-# Revision 1.2  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.1  2007/06/22 02:16:52  brian
-# - initial commit of functions and documentation for Sortino's Upside
-# Potential Ratio
+# $Id: UpsidePotentialRatio.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
