@@ -1,5 +1,4 @@
-`chart.Bar` <-
-function (R, legend.loc = NULL, colorset = (1:12), ...)
+chart.Bar <- function (R, legend.loc = NULL, colorset = (1:12), ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -27,30 +26,9 @@ function (R, legend.loc = NULL, colorset = (1:12), ...)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Bar.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.6  2009-03-06 03:06:44  peter
-# - changed checkData to use default xts
-#
-# Revision 1.5  2008-10-16 18:45:37  brian
-# - use checkData with method="zoo" instead of checkDataMatrix
-#
-# Revision 1.4  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.3  2007/11/18 14:28:02  peter
-# - squared off the bar ends
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: chart.Bar.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
