@@ -1,4 +1,4 @@
-`chart.Correlation` <-
+chart.Correlation <-
 function (R, histogram = TRUE, ...)
 { # @author R Development Core Team
   # @author modified by Peter Carl
@@ -56,35 +56,9 @@ function (R, histogram = TRUE, ...)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Correlation.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.7  2009-10-10 12:40:08  brian
-# - update copyright to 2004-2009
-#
-# Revision 1.6  2009-06-02 03:23:09  peter
-# - removed pch change, should parameterize it instead
-#
-# Revision 1.5  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.4  2008/01/18 04:05:15  peter
-# - fixed missing values in density
-# - removed y as unnecessary parameter
-#
-# Revision 1.3  2007/12/27 18:44:36  peter
-# - added option for passing parameters to cor, including
-# "pairwise.complete.obs"
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: chart.Correlation.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
