@@ -1,4 +1,4 @@
-`chart.CumReturns` <-
+chart.CumReturns <-
 function (R, wealth.index = FALSE, geometric = TRUE, legend.loc = NULL, colorset = (1:12), begin = c("first","axis"), ...)
 { # @author Peter Carl
 
@@ -90,55 +90,9 @@ function (R, wealth.index = FALSE, geometric = TRUE, legend.loc = NULL, colorset
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.CumReturns.R 1510 2010-01-04 03:41:19Z peter_carl $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.13  2009-09-01 20:18:41  brian
-# - add comments to describe the handling of na.skip for rbind'ing correct start value to shorter series
-#
-# Revision 1.12  2009-09-01 20:05:44  brian
-# - add na.skip to reference.index
-# - revise start.index handling to be more programatically efficient
-# - revise start.index handling for binding later-starting series to the "current" value of the first series
-#
-# Revision 1.11  2009-08-31 21:20:20  brian
-# - fix return accumulation after adding na.skip
-#
-# Revision 1.10  2009-08-31 20:51:27  brian
-# - add new function na.skip to deal with non-contiguous NA's in data, may eventually go to xts
-# - fix components of charts.PerformanceSummary to use na.skip
-#
-# Revision 1.9  2009-03-20 03:22:53  peter
-# - added xts
-#
-# Revision 1.8  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.7  2007/06/18 03:34:33  brian
-# - reverse default order of 'begin' argument to match charts.PerformanceSummary
-#
-# Revision 1.6  2007/04/25 20:06:28  peter
-# - changed the 'method' tag to 'begin'
-#
-# Revision 1.5  2007/04/20 13:47:53  peter
-# - added attribute 'method' with values of 'axis' and 'first' to indicate
-#   where to attach shorter data lengths for comparison
-#
-# Revision 1.4  2007/03/13 03:59:26  peter
-# - uses new checkData function
-#
-# Revision 1.3  2007/03/10 05:08:04  peter
-# - revised function to take zoo objects and plot unequal time periods
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: chart.CumReturns.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
