@@ -1,4 +1,4 @@
-`charts.BarVaR` <-
+charts.BarVaR <-
 function (R, main = "Returns", cex.legend = 0.8, colorset=1:12, ...)
 { # @author Peter Carl
 
@@ -51,24 +51,9 @@ function (R, main = "Returns", cex.legend = 0.8, colorset=1:12, ...)
 #
 # Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.BarVaR.R 1638 2010-03-17 04:37:37Z peter_carl $
+# $Id: charts.BarVaR.R 1730 2010-08-03 19:31:06Z braverock $
 #
-###############################################################################
-# $Log: charts.BarVaR.R,v $
-# Revision 1.1  2009-09-17 03:48:40  peter
-# - first commit of function
-#
-# Revision 1.1  2009-08-18 21:24:00  peter
-# - multiple bar plots function
-#
-# Revision 1.2  2008-04-18 03:59:52  peter
-# - added na.omit to avoid problems with missing data
-#
-# Revision 1.1  2008/02/23 05:55:21  peter
-# - chart demonstrating fund exposures through time
-#
-#
-###############################################################################
+###############################################################################
\ No newline at end of file
