@@ -1,4 +1,4 @@
-`charts.RollingPerformance` <-
+charts.RollingPerformance <-
 function (R, width = 12, Rf = 0, main = NULL, trim = TRUE, event.labels = NULL, legend.loc=NULL, ...)
 { # @author Peter Carl
 
@@ -70,53 +70,9 @@ function (R, width = 12, Rf = 0, main = NULL, trim = TRUE, event.labels = NULL,
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.RollingPerformance.R 1503 2010-01-02 11:48:32Z braverock $
+# $Id: charts.RollingPerformance.R 1730 2010-08-03 19:31:06Z braverock $
 #
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.12  2009-10-10 12:40:08  brian
-# - update copyright to 2004-2009
-#
-# Revision 1.11  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.10  2009-10-02 18:57:47  peter
-# - changed parameter Rf to Rf
-#
-# Revision 1.9  2009-03-20 03:22:53  peter
-# - added xts
-#
-# Revision 1.8  2008-10-14 14:37:29  brian
-# - convert from matrix or data.frame to zoo in checkData call
-#
-# Revision 1.7  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.6  2008-04-18 03:52:44  peter
-# - added par to reset layout to default
-#
-# Revision 1.5  2007/10/03 02:44:46  peter
-# - legend will be hidden by default
-# - legend location can be passed in through legend.loc parameter
-#
-# Revision 1.4  2007/06/29 15:53:16  peter
-# - removed plot.new() that was causing two page pdfs
-#
-# Revision 1.3  2007/03/13 04:23:04  peter
-# - changed to checkData function
-# - modified parameters to fit RollingPerformance changes
-# - now takes unequal time periods
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
-#
-###############################################################################
+###############################################################################
\ No newline at end of file
