@@ -1,5 +1,4 @@
-`table.CAPM` <-
-function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
+table.CAPM <- function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
 {# @author Peter Carl
 
     # DESCRIPTION:
@@ -59,6 +58,8 @@ function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
             model.lm = lm(merged.assets[,1] ~ merged.assets[,2])
             alpha = coef(model.lm)[[1]]
             beta = coef(model.lm)[[2]]
+			CAPMbull = CAPM.beta.bull(Ra[,column.a], Rb[,column.b],Rf) #inefficient, recalcs excess returns and intercept 
+			CAPMbear = CAPM.beta.bear(Ra[,column.a], Rb[,column.b],Rf) #inefficient, recalcs excess returns and intercept
             htest = cor.test(merged.assets[,1], merged.assets[,2])
             active.premium = (Return.annualized(merged.assets[,1,drop=FALSE], scale = scale) - Return.annualized(merged.assets[,2,drop=FALSE], scale = scale))
             tracking.error = sqrt(sum(merged.assets[,1] - merged.assets[,2])^2/(length(merged.assets[,1])-1)) * sqrt(scale)
@@ -67,8 +68,8 @@ function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
             z = c(
                     alpha,
                     beta,
-                    CAPM.beta.bull(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE]), #inefficient
-                    CAPM.beta.bear(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE]), #inefficient
+                    CAPMbull, 
+                    CAPMbear,
                     summary(model.lm)$r.squared,
                     ((1+alpha)^scale - 1),
                     htest$estimate,
@@ -115,62 +116,9 @@ function (Ra, Rb, scale = NA, Rf = 0, digits = 4)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.CAPM.R 1503 2010-01-02 11:48:32Z braverock $
-#
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.15  2009-10-10 12:40:08  brian
-# - update copyright to 2004-2009
-#
-# Revision 1.14  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.13  2009-10-02 19:17:08  peter
-# - added up and down market beta measures
-#
-# Revision 1.12  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.11  2007/03/22 13:48:51  peter
-# - removed and edited comments
-#
-# Revision 1.10  2007/03/22 11:34:12  peter
-# - changed the colname label connector from "vs" to "to"
-#
-# Revision 1.9  2007/03/22 01:24:17  peter
-# - shortened col labels
-#
-# Revision 1.8  2007/03/22 01:03:16  peter
-# - handles uneven periods of data
-# - handles matrixes of assets and benchmarks
-# - uses checkData
-#
-# Revision 1.7  2007/03/02 17:41:48  brian
-# - remove redundant comments
-#
-# Revision 1.6  2007/02/28 03:22:39  peter
-# - added checkDataVector function to Rf
-#
-# Revision 1.5  2007/02/26 22:04:36  brian
-# - changes in functions to pass "R CMD check" for package
-#
-# Revision 1.4  2007/02/25 18:23:40  brian
-# - change call to round() to call base::round() to fix conflict with newest fCalendar
-#
-# Revision 1.3  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.2  2007/02/07 13:20:52  brian
-# - change Ri to Rb for benchmark asset to standardize parameters
-# - change indexReturns.vec to benchmarkReturns.vec for consistency
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
+# $Id: table.CAPM.R 1730 2010-08-03 19:31:06Z braverock $
 #
 ###############################################################################
\ No newline at end of file
