@@ -1,4 +1,4 @@
-`table.DownsideRisk` <-
+table.DownsideRisk <-
 function (R, ci = 0.95, scale = NA, Rf = 0, MAR = .1/12, p= 0.95, digits = 4)
 {# @author Peter Carl
 
@@ -104,56 +104,9 @@ function (R, ci = 0.95, scale = NA, Rf = 0, MAR = .1/12, p= 0.95, digits = 4)
 #
 # Copyright (c) 2004-2010 Peter Carl and Brian G. Peterson
 #
-# This library is distributed under the terms of the GNU Public License (GPL)
+# This R package is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.DownsideRisk.R 1503 2010-01-02 11:48:32Z braverock $
+# $Id: table.DownsideRisk.R 1730 2010-08-03 19:31:06Z braverock $
 #
-###############################################################################
-# $Log: not supported by cvs2svn $
-# Revision 1.13  2009-10-08 19:47:59  peter
-# - added scale check
-#
-# Revision 1.12  2009-10-03 18:23:55  brian
-# - multiple Code-Doc mismatches cleaned up for R CMD check
-# - further rationalized use of R,Ra,Rf
-# - rationalized use of period/scale
-#
-# Revision 1.11  2009-04-15 21:50:10  peter
-# - fixed calculation using subset on zoo object
-# - passing in column using drop=FALSE to preserve names
-#
-# Revision 1.10  2008-10-14 14:37:29  brian
-# - convert from matrix or data.frame to zoo in checkData call
-#
-# Revision 1.9  2008-06-02 16:05:19  brian
-# - update copyright to 2004-2008
-#
-# Revision 1.8  2007/08/29 03:17:24  peter
-# - fixed NA removal problems
-# - fixed rounding issue with Rf labels in table
-#
-# Revision 1.7  2007/08/16 14:47:40  peter
-# - added subset handling for when Rf is a time series rather than a point
-# est
-#
-# Revision 1.6  2007/04/10 01:43:38  peter
-# - cleanup to prevent warning about names from checkData
-#
-# Revision 1.5  2007/03/22 14:39:45  peter
-# - uses checkData
-#
-# Revision 1.4  2007/03/04 20:59:27  brian
-# - minor changes to pass R CMD check
-#
-# Revision 1.3  2007/02/25 18:23:40  brian
-# - change call to round() to call base::round() to fix conflict with newest fCalendar
-#
-# Revision 1.2  2007/02/07 13:24:49  brian
-# - fix pervasive comment typo
-#
-# Revision 1.1  2007/02/02 19:06:15  brian
-# - Initial Revision of packaged files to version control
-# Bug 890
-#
-###############################################################################
+###############################################################################
\ No newline at end of file
